pub enum ActorSignal {
Term,
}Expand description
Messages that can be sent to any actor, regardless of its receiving type.
There are some messages that you need to be able to send to any actor, regardless of what type
that actor receives. Most of these messages concern the lifetime and execution of the actor.
An actor of any type can be sent an ActorSignal.
Variants
Term
Terminates the actor gracefully.